@@ -1,24 +1,25 @@
 /*
- *  libzvbi - DVB VBI demultiplexer
+ *  libzvbi -- DVB VBI demultiplexer
  *
  *  Copyright (C) 2004, 2006, 2007 Michael H. Schimek
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the 
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ *  Boston, MA  02110-1301  USA.
  */
 
-/* $Id: dvb_demux.c,v 1.21 2007/11/27 17:51:29 mschimek Exp $ */
+/* $Id: dvb_demux.c,v 1.23 2008/02/19 00:35:15 mschimek Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
@@ -1371,7 +1372,7 @@ decode_timestamp		(vbi_dvb_demux *	dx,
 }
 
 static vbi_bool
-valid_pes_packet_header		(vbi_dvb_demux *	dx,
+valid_vbi_pes_packet_header	(vbi_dvb_demux *	dx,
 				 const uint8_t *	p)
 {
 	unsigned int header_length;
@@ -1664,7 +1665,17 @@ demux_pes_packet		(vbi_dvb_demux *	dx,
 				++p;
 			} else if (PRIVATE_STREAM_1 == p[3]) {
 				break;
-			} else if (p[3] >= 0xBC) {
+			} else if (p[3] < 0xBC) {
+				++p;
+			} else {
+				/* ISO/IEC 13818-1 Table 2-19 stream_id
+				   assignments: 0xBC ... 0xFF. */
+
+				/* XXX We shouldn't take this shortcut
+				   unless we're sure this is a PES packet
+				   header and not some random junk, so we
+				   don't miss any data. */
+
 				packet_length = p[4] * 256 + p[5];
 
 				/* Not a VBI PES packet, skip it. */
@@ -1701,7 +1712,7 @@ demux_pes_packet		(vbi_dvb_demux *	dx,
 		if (packet_length < 178)
 			continue;
 
-		if (!valid_pes_packet_header (dx, p))
+		if (!valid_vbi_pes_packet_header (dx, p))
 			continue;
 
 		/* Habemus packet. Skip all data up to the header,
@@ -1835,7 +1846,7 @@ demux_ts_packet			(vbi_dvb_demux *	dx,
 				if (0)
 					log_block (dx, p, left);
 
-				if (!valid_pes_packet_header (dx, p)) {
+				if (!valid_vbi_pes_packet_header (dx, p)) {
 					/* Discard the data collected
 					   so far. */
 					dx->new_frame = TRUE;
