@@ -1,24 +1,25 @@
 /*
- *  libzvbi - DVB VBI demultiplexer
+ *  libzvbi -- DVB VBI demultiplexer
  *
  *  Copyright (C) 2004, 2007 Michael H. Schimek
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the 
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ *  Boston, MA  02110-1301  USA.
  */
 
-/* $Id: dvb_demux.h,v 1.9 2007/11/27 17:42:23 mschimek Exp $ */
+/* $Id: dvb_demux.h,v 1.11 2008/02/24 14:17:54 mschimek Exp $ */
 
 #ifndef __ZVBI_DVB_DEMUX_H__
 #define __ZVBI_DVB_DEMUX_H__
@@ -94,7 +95,7 @@ vbi_dvb_pes_demux_new		(vbi_dvb_demux_cb *	callback,
 vbi_bool
 _vbi_dvb_skip_data_unit		(const uint8_t **	buffer,
 				 unsigned int *		buffer_left)
-  _vbi_attribute ((_vbi_nonnull (1, 2)));
+  _vbi_nonnull ((1, 2));
 /* Experimental. */
 vbi_bool
 _vbi_dvb_demultiplex_sliced	(vbi_sliced *		sliced,
@@ -102,7 +103,7 @@ _vbi_dvb_demultiplex_sliced	(vbi_sliced *		sliced,
 				 unsigned int		max_lines,
 				 const uint8_t **	buffer,
 				 unsigned int *		buffer_left)
-  _vbi_attribute ((_vbi_nonnull (1, 2, 4, 5)));
+  _vbi_nonnull ((1, 2, 4, 5));
 /* Experimental. */
 extern vbi_dvb_demux *
 _vbi_dvb_ts_demux_new		(vbi_dvb_demux_cb *	callback,
