@@ -1,24 +1,25 @@
 /*
- *  libzvbi - VBI device simulation
+ *  libzvbi -- VBI device simulation
  *
- *  Copyright (C) 2004 Michael H. Schimek
+ *  Copyright (C) 2004, 2007 Michael H. Schimek
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the 
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ *  Boston, MA  02110-1301  USA.
  */
 
-/* $Id: io-sim.c,v 1.16 2007/11/27 17:50:59 mschimek Exp $ */
+/* $Id: io-sim.c,v 1.17 2008/02/19 00:35:20 mschimek Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
@@ -1116,6 +1117,9 @@ _vbi_raw_video_image		(uint8_t *		raw,
 		case VBI_PIXFMT_YUV410:
 		case VBI_PIXFMT_YVU410:
 		case VBI_PIXFMT_Y8:
+#endif
+#if 2 == VBI_VERSION_MINOR
+		case VBI_PIXFMT_PAL8:
 #endif
 		case VBI_PIXFMT_YUV420:
 			for (i = 0; i < samples_per_line; ++i)
