@@ -1,26 +1,27 @@
 /*
- *  libzvbi - V4L interface
+ *  libzvbi -- Video For Linux driver interface
  *
  *  Copyright (C) 1999-2004 Michael H. Schimek
  *  Copyright (C) 2003, 2004 Tom Zoerner
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the 
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ *  Boston, MA  02110-1301  USA.
  */
 
 static const char rcsid [] =
-"$Id: io-v4l.c,v 1.36 2007/11/27 17:42:01 mschimek Exp $";
+"$Id: io-v4l.c,v 1.38 2008/02/24 14:17:28 mschimek Exp $";
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
@@ -63,7 +64,7 @@ static const char rcsid [] =
 /* Custom ioctl of the bttv driver. */
 #define BTTV_VBISIZE		_IOR('v' , BASE_VIDIOCPRIVATE+8, int)
 static __inline__ void IOCTL_ARG_TYPE_CHECK_BTTV_VBISIZE
-  (const int *arg _vbi_attribute ((unused))) {}
+  (const int *arg _vbi_unused) {}
 
 #undef REQUIRE_SELECT
 #undef REQUIRE_SVBIFMT		/* else accept current parameters */
