@@ -3,22 +3,23 @@
  *
  *  Copyright (C) 2000, 2001 Michael H. Schimek
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the 
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ *  Boston, MA  02110-1301  USA.
  */
 
-/* $Id: lang.c,v 1.11 2007/11/27 17:55:35 mschimek Exp $ */
+/* $Id: lang.c,v 1.14 2008/02/19 00:35:20 mschimek Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
@@ -850,20 +851,24 @@ vbi_caption_unicode		(unsigned int		c,
 {
 	to_upper = !!to_upper;
 
+	/* Note the comparisons are sorted for shortest path. */
 	if (likely (c < 0x80)) {
 		if (likely (c >= 0x20)) {
 			return caption[c - 0x20][to_upper];
 		}
 	} else {
-		c &= ~0x0700;
+		c &= ~0x0800; /* ignore channel bit */
 
 		if (c < 0x1240) {
 			if (c < 0x1140 && c >= 0x1130) {
+				/* 001 c001  011 xxxx */
 				return caption_special[c - 0x1130][to_upper];
 			} else if (c >= 0x1220) {
+				/* 001 c010  01x xxxx */
 				return caption_extended2[c - 0x1220][to_upper];
 			}
 		} else if (c < 0x1340 && c >= 0x1320) {
+			/* 001 c011  01x xxxx */
 			return caption_extended3[c - 0x1320][to_upper];
 		}
 	}
